/*
 * utime.h
 */


#ifndef share_utime_h
#define share_utime_h


#ifndef ASM_FILE


#include<sys/types.h>


struct utimbuf{
	time_t    actime;	/* Access time. */
	time_t    modtime;	/* Modification time. */
};


#endif

#endif
